@@ -10,6 +10,7 @@ __all__ = [
     'TestCaseException',
     'InvalidOutputsException',
     'SkippedTestCaseException',
+    'TimeoutException',
 ]
 
 
@@ -26,3 +27,8 @@ class InvalidOutputsException(TestCaseException):
 class SkippedTestCaseException(TestCaseException):
     """ Exception raised that indicates that a test case should be skipped """
     pass  # pragma: no cover
+
+
+class TimeoutException(TestCaseException):
+    """ Exception raised that indicates that a test case timed out """
+    pass  # pragma: no cover
